@@ -400,6 +400,7 @@ def do_call(args, kwargs, fn_name=None, live_object=None): # Yes, I do mean args
     if 'response' in r:
         return r['response']
     if 'error' in r:
-        raise _server._deserialise_exception(r["error"])
+        error_from_server = _server._deserialise_exception(r["error"])
+        raise error_from_server
     else:
         raise Exception("Bogus response from server: " + repr(r))
